<template>

	<div class="app-container">

		<!-- <van-pull-refresh class="mobile-app-container" v-model="loading" :success-text="$store.state.data.successText"
			@refresh="handlePullDownRefresh">
			<van-sticky :offset-top="$store.state.data.showNavBar?46:0">
				<van-search class="solid-bottom" v-model="queryParams.PaymentDetailsName" show-action placeholder="请输入搜索关键词"
					@search="handleQuery">
					<template #action>
						<div @click="handleQuery">搜索</div>
					</template>
				</van-search>
			</van-sticky>
			<van-list v-model:loading="loading" :finished="PaymentDetailsList.length >= total"
				:finished-text="$store.state.data.finishedText" @load="handleReachBottom"
				v-if="PaymentDetailsList.length > 0">
				<template v-for="item in PaymentDetailsList" :key="item.PaymentDetailsId">
					<van-cell-group class="margin-tb-xs">
						<van-cell title="设备金额" :value="item.id" />
						<van-cell title="设备" :value="item.configId" />
						<van-cell title="月份" :value="item.year" />
						<van-cell title="订单号" :value="item.orderNumer" />
						<van-cell title="设备金额" :value="item.configMoney" />
					</van-cell-group>
				</template>
			</van-list>
			<van-skeleton :row="$columns.size" v-if="loading" />
			<van-empty :description="$store.state.data.emptyDescription"
				v-else-if="loading == false&&PaymentDetailsList.length == 0" />
		
		
		</van-pull-refresh>
		 -->

		<el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch" label-width="68px">
			<el-form-item label="设备" prop="configId">
				<el-input v-model="queryParams.configId" placeholder="请输入设备" clearable @keyup.enter="handleQuery" />
			</el-form-item>
			<el-form-item label="月份" prop="year">
				<el-input v-model="queryParams.year" placeholder="请输入月份" clearable @keyup.enter="handleQuery" />
			</el-form-item>
			<el-form-item label="订单号" prop="orderNumer">
				<el-input v-model="queryParams.orderNumer" placeholder="请输入订单号" clearable @keyup.enter="handleQuery" />
			</el-form-item>
			<!-- <el-form-item label="设备金额" prop="configMoney">
				<el-input v-model="queryParams.configMoney" placeholder="请输入设备金额" clearable
					@keyup.enter="handleQuery" />
			</el-form-item> -->
			<el-form-item>
				<el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
				<el-button icon="Refresh" @click="resetQuery">重置</el-button>
			</el-form-item>
		</el-form>

		<el-row :gutter="10" class="mb8">
		<!-- 	<el-col :span="1.5">
				<el-button type="primary" plain icon="Plus" @click="handleAdd"
					v-hasPermi="['PaymentDetails:PaymentDetails:add']">新增
				</el-button>
			</el-col>
			<el-col :span="1.5">
				<el-button type="success" plain icon="Edit" :disabled="single" @click="handleUpdate"
					v-hasPermi="['PaymentDetails:PaymentDetails:edit']">修改
				</el-button>
			</el-col>
			<el-col :span="1.5">
				<el-button type="danger" plain icon="Delete" :disabled="multiple" @click="handleDelete"
					v-hasPermi="['PaymentDetails:PaymentDetails:remove']">删除
				</el-button>
			</el-col> -->
			<el-col :span="1.5">
				<el-button type="warning" plain icon="Download" @click="handleExport"
					v-hasPermi="['PaymentDetails:PaymentDetails:export']">导出
				</el-button>
			</el-col>
			<right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar>
		</el-row>

		<el-table v-loading="loading" :data="PaymentDetailsList" @selection-change="handleSelectionChange">
			<el-table-column label="订单号" align="center" prop="orderNumer" />
			<el-table-column label="设备" align="center" prop="configId"/>
			<el-table-column label="月份" align="center" prop="year" >
				<template #default="scope">
					<span class="">{{scope.row.year}}个月</span>
				</template>
			</el-table-column>
			<el-table-column label="设备金额" align="center" prop="configMoney" >
				<template #default="scope">
					<span class="text-price">{{scope.row.configMoney}}</span>
				</template>
			</el-table-column>
			<!-- <el-table-column type="selection" width="55" align="center" />
			<el-table-column label="设备金额" align="center" prop="id" />
			<el-table-column label="设备" align="center" prop="configId" />
			<el-table-column label="月份" align="center" prop="year" />
			<el-table-column label="订单号" align="center" prop="orderNumer" />
			<el-table-column label="设备金额" align="center" prop="configMoney" />
			<el-table-column label="操作" align="center" class-name="small-padding fixed-width">
				<template #default="scope">
					<el-button type="text" icon="Edit" @click="handleUpdate(scope.row)"
						v-hasPermi="['PaymentDetails:PaymentDetails:edit']">修改
					</el-button>
					<el-button type="text" icon="Delete" @click="handleDelete(scope.row)"
						v-hasPermi="['PaymentDetails:PaymentDetails:remove']">删除
					</el-button>
				</template>
			</el-table-column> -->
		</el-table>

		<pagination v-show="total>0" :total="total" v-model:page="queryParams.pageNum"
			v-model:limit="queryParams.pageSize" @pagination="getList" />

		<!-- 添加或修改订单详情对话框 -->
		<el-dialog :title="title" v-model="open" width="500px" append-to-body>
			<el-form ref="PaymentDetailsRef" :model="form" :rules="rules" label-width="80px">
				<el-form-item label="设备" prop="configId">
					<el-input v-model="form.configId" placeholder="请输入设备" />
				</el-form-item>
				<el-form-item label="月份" prop="year">
					<el-input v-model="form.year" placeholder="请输入月份" />
				</el-form-item>
				<el-form-item label="订单号" prop="orderNumer">
					<el-input v-model="form.orderNumer" placeholder="请输入订单号" />
				</el-form-item>
				<el-form-item label="设备金额" prop="configMoney">
					<el-input v-model="form.configMoney" placeholder="请输入设备金额" />
				</el-form-item>
			</el-form>
			<template #footer>
				<div class="dialog-footer">
					<el-button type="primary" @click="submitForm">确 定</el-button>
					<el-button @click="cancel">取 消</el-button>
				</div>
			</template>
		</el-dialog>
	</div>





</template>

<script setup name="PaymentDetails">
	import {
		listPaymentDetails,
		getPaymentDetails,
		delPaymentDetails,
		addPaymentDetails,
		updatePaymentDetails
	} from "@/api/PaymentDetails/PaymentDetails";

	const {
		proxy
	} = getCurrentInstance();
	
	const PaymentDetailsList = ref([]);
	const open = ref(false);
	const loading = ref(true);
	const showSearch = ref(true);
	const ids = ref([]);
	const single = ref(true);
	const multiple = ref(true);
	const total = ref(0);
	const title = ref("");

	const data = reactive({
		form: {},
		queryParams: {
			pageNum: 1,
			pageSize: 10,
			configId: null,
			year: null,
			orderNumer: null,
			configMoney: null
		},
		rules: {
			configId: [{
				required: true,
				message: "设备不能为空",
				trigger: "blur"
			}],
			year: [{
				required: true,
				message: "月份不能为空",
				trigger: "blur"
			}],
			orderNumer: [{
				required: true,
				message: "订单号不能为空",
				trigger: "blur"
			}],
		}
	});

	const {
		queryParams,
		form,
		rules
	} = toRefs(data);
	const baseUrl =
		import.meta.env.VITE_APP_BASE_API;

	/** 查询订单详情列表 */
	function getList() {
		loading.value = true;
		listPaymentDetails(queryParams.value).then(response => {
			PaymentDetailsList.value = response.rows;
			total.value = response.total;
			loading.value = false;
		});
	}

	function addList() {
		loading.value = true;
		listPaymentDetails(queryParams.value)
			.then(response => {
				PaymentDetailsList.value.push(...response.rows);
				total.value = response.total;
				if (PaymentDetailsList.value.length >= total.value) finished.value = true;
				loading.value = false;
			})
			.catch(response => {
				loading.value = false;
			});
	}

	// 下拉刷新
	function handlePullDownRefresh() {
		queryParams.value.pageNum = 1;
		PaymentDetailsList.value = [];
		addList();
	}

	// 滚动到底部的事件
	function handleReachBottom() {
		queryParams.value.pageNum++;
		addList();
	}

	// 取消按钮
	function cancel() {
		open.value = false;
		reset();
	}

	// 表单重置
	function reset() {
		form.value = {
			id: null,
			configId: null,
			year: null,
			orderNumer: null,
			configMoney: null
		};
		proxy.resetForm("PaymentDetailsRef");
	}

	/** 搜索按钮操作 */
	function handleQuery() {
		queryParams.value.pageNum = 1;
		getList();
	}

	/** 重置按钮操作 */
	function resetQuery() {
		proxy.resetForm("queryRef");
		handleQuery();
	}

	// 多选框选中数据
	function handleSelectionChange(selection) {
		ids.value = selection.map(item => item.id);
		single.value = selection.length != 1;
		multiple.value = !selection.length;
	}

	/** 新增按钮操作 */
	function handleAdd() {
		reset();
		open.value = true;
		title.value = "添加订单详情";
	}

	/** 修改按钮操作 */
	function handleUpdate(row) {
		reset();
		const id =
			row.id || ids.value
		getPaymentDetails(id).then(response => {
			form.value = response.data;
			open.value = true;
			title.value = "修改订单详情";
		});
	}

	/** 提交按钮 */
	function submitForm() {
		proxy.$refs["PaymentDetailsRef"].validate(valid => {
			if (valid) {
				if (form.value.id != null) {
					updatePaymentDetails(form.value).then(response => {
						proxy.$modal.msgSuccess("修改成功");
						open.value = false;
						getList();
					});
				} else {
					addPaymentDetails(form.value).then(response => {
						proxy.$modal.msgSuccess("新增成功");
						open.value = false;
						getList();
					});
				}
			}
		});
	}

	/** 删除按钮操作 */
	function handleDelete(row) {
		const ids = row.id || ids.value;
		proxy.$modal.confirm('是否确认删除订单详情编号为"' + ids + '"的数据项？').then(function() {
			return delPaymentDetails(ids);
		}).then(() => {
			getList();
			proxy.$modal.msgSuccess("删除成功");
		}).catch(() => {});
	}

	/** 导出按钮操作 */
	function handleExport() {
		downloadPaymentDetails(queryParams.value)
		// proxy.download('PaymentDetails/PaymentDetails/export', {
		//   ...queryParams.value
		// }, `PaymentDetails_${new Date().getTime()}.xlsx`)
	}

	getList();
</script>
